@@ -22,7 +22,7 @@ _EOF_
 
 artixpkg_version_print() {
     cat <<- _EOF_
-    artixpkg 0.37.6-1-any
+    artixpkg 0.38-1-any
 _EOF_
 }
 
